ComplementResult

Enum ComplementResult 

pub enum ComplementResult<C> {
    Single(C),
    Split(C, C),
}
Represents the result of a complement

Variants



Single(C)

Complement was successful and resulted in a single element



Split(C, C)

Complement was successful and resulted in two elements

Implementations

Source

impl<C> ComplementResult<C>

pub fn is_single(&self) -> bool

Whether the ComplementResult is of the Single variant

Examples
assert!(ComplementResult::<u8>::Single(10).is_single());
assert!(!ComplementResult::<u8>::Split(10, 20).is_single());
pub fn is_split(&self) -> bool

Whether the ComplementResult is of the Split variant

Examples
assert!(ComplementResult::<u8>::Split(10, 20).is_split());
assert!(!ComplementResult::<u8>::Single(10).is_split());
pub fn single(self) -> Option<C>

Returns the content of the Single variant

This operation consumes self and puts the content of the Single variant in an Option. If instead self is another variant, this method returns None.

Examples
assert_eq!(ComplementResult::<u8>::Single(10).single(), Some(10));
assert_eq!(ComplementResult::<u8>::Split(10, 20).single(), None);
pub fn split(self) -> Option<(C, C)>

Returns the content of the Split variant

This operation consumes self and puts the content of the Split variant in an Option. If instead self is another variant, this method returns None.

Examples
assert_eq!(
    ComplementResult::<u8>::Split(10, 20).split(),
    Some((10, 20))
);
assert_eq!(ComplementResult::<u8>::Single(10).split(), None);
pub fn map<F, T>(self, f: F) -> ComplementResult<T>
where F: FnMut(C) -> T,

Maps the contents of the variants using the given transformation closure

Examples
assert_eq!(
    ComplementResult::<u8>::Single(10).map(|x| x * 2),
    ComplementResult::<u8>::Single(20),
);
assert_eq!(
    ComplementResult::<u8>::Split(10, 20).map(|x| x * 2),
    ComplementResult::<u8>::Split(20, 40),
);